<script>import { get_current_component } from 'svelte/internal';
import { createEventForwarder, useActions } from '../../internal';
import { randomID } from '../../styles';
import { Input } from '../Input';
import { InputWrapper } from '../InputWrapper';
export let use = [], element = undefined, className = '', override = {}, label = '', description = null, error = null, required = false, labelProps = {}, descriptionProps = {}, errorProps = {}, invalid = false, id = randomID('textarea'), labelElement = 'label', showRightSection = undefined, value = '', placeholder = '';
export { className as class };
/** An action that forwards inner dom node events from parent component */
const forwardEvents = createEventForwarder(get_current_component());
// Flag that enables the override of the right section slot
// of the Input component only if it was provided
const _showRightSection = showRightSection === undefined ? !!$$slots.rightSection : showRightSection;
$: _invalid = invalid || !!error;
</script>

<!--
@component

Multiline text input.

@see https://svelteui.dev/core/textarea
@example
    ```tsx
    <Textarea
      label='Comment'
      description="Tell us what's on your mind"
      placeholder='Blah blah blah'
      required
    />
    ```
-->

<InputWrapper
	bind:element
	class={className}
	{override}
	{label}
	{description}
	{error}
	{required}
	{labelProps}
	{descriptionProps}
	{errorProps}
	{id}
	{labelElement}
>
	<Input
		bind:value
		{required}
		{id}
		{placeholder}
		{...$$restProps}
		use={[forwardEvents, [useActions, use]]}
		invalid={_invalid}
		showRightSection={_showRightSection}
		root="textarea"
		multiline
	>
		<slot slot="rightSection" name="rightSection" />
	</Input>
</InputWrapper>
